import os
import shutil
import tempfile
import unittest
from unittest import mock

from charmhelpers.core import unitdata

from .. import squid


class SquidTestCase(unittest.TestCase):
    def setUp(self):
        self.maxDiff = None
        patcher = mock.patch('charmhelpers.core.hookenv.config')
        self.mock_config = patcher.start()
        self.addCleanup(patcher.stop)

        self.tmpdir = tempfile.mkdtemp(prefix='charm-unittests-')
        self.addCleanup(shutil.rmtree, self.tmpdir)
        os.environ['UNIT_STATE_DB'] = os.path.join(self.tmpdir, '.unit-state.db')
        unitdata.kv().set('squid-cache-disk', 5000)
        unitdata.kv().set('squid-disk-caches', [('/srv', 2000)])

    def test_squid_cache_size(self):
        self.mock_config.return_value = {
            'squid-cache-disk': 20 * 1024,
            'squid-disk-caches': [['/srv', 2000]],
            'cache-storage-size': 0,
        }
        result = squid.cache_dirs()
        self.assertEqual(result, 'cache_dir aufs /srv 2000 16 256\n')

        self.mock_config.return_value = {
            'squid-cache-disk': 20 * 1024,
            'squid-disk-caches': [['/srv', 2000]],
            'cache-storage-size': 1000,
        }
        result = squid.cache_dirs()
        self.assertEqual(result, 'cache_dir aufs /srv 1000 16 256\n')
